/*
 *This is application code of Great Little Radio Player
 *It is written by Dejan Petrovic
 *dekiseka.petrovic@gmail.com
 */

#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "adddialog.h"
#include "settings.h"

#include "phonon/AudioDataOutput"
#include "phonon/Global"
#include "phonon/MediaObject"
#include "phonon/AudioOutput"
#include <phonon/MediaSource>
#include <phonon/BackendCapabilities>
#include <phonon/phonon>

#include <QtCore/QFile>
#include <QDir>
#include "QtGui"
#include <QtCore/QTextStream>
#include <QDialog>
#include <QAction>
#include <QMenu>
#include "QMessageBox"
#include "QStringRef"
#include <QTimer>
#include "QPixmap"
#include "QDesktopWidget"
#include "QPushButton"
#include <QDesktopWidget>
#include <QList>
#include <QPixmap>
#include "QTableWidgetItem"
#include <QFlags>
#include <QRegExp>
#include <QStringList>
#include <QSettings>
#include <QPalette>

Phonon::MediaObject *music;
Phonon::AudioOutput *audioOutput;
QTableWidget *tableWidget;
QTimer *MainTimer;

QString StationLabelString;
QString IMGLabel_StatusString;
QString StationLabelStatusString;
QString StationNameStatusFont;
QString PlayName;
QString PlayAddress;
QString PlayCountry;
QString PlayGenre;
QString PlayFavorite;

QAction *StopMenuItem;
QAction *ShowHide;

Phonon::MediaObject *metaInformationResolver;
QString PathToStationsDir;
QString PathToDestLanguageDir;
QString PathToOrigLanguageDir;
QString PathToStationsFile;
QStringList FilterList;

bool StatusGenre;
bool StatusCountry;

//------------------------------------------------------------------------------------
MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent), ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    MainTimer = new QTimer;
    connect(MainTimer, SIGNAL(timeout()), this, SLOT(CheckIfStationRunning()));

    //Procitaj i postavi jezik
    QSettings temp_settings("glrp", "Great Little Radio Player");
    temp_settings.beginGroup("OtherSettings");
    ReadLanguage(temp_settings.value("UILanguage", "English").toString());
    temp_settings.endGroup();
    //-----------------------

    music = new Phonon::MediaObject(this);
    music->setObjectName("music");
    audioOutput = new Phonon::AudioOutput(this);
    audioOutput->setObjectName("audioOutput");
    Phonon::createPath(music, audioOutput);

    tableWidget = new QTableWidget();

    SloveIfStationFileNotExists();
    Load_stations(PathToStationsFile);
    RefreshGenreCountryList("Genre");
    StatusGenre = true;
    on_actionList_all_Favorites_triggered();

    ui->widget->hide();

    ui->StationslistWidget->setContextMenuPolicy(Qt::CustomContextMenu);
    connect(ui->StationslistWidget, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(ShowContextMenu(const QPoint&)));

    try
    {
    setWindowIcon(QIcon(":/images/IMG/radio-tray-white-48.svg"));
    }
    catch(...){}

    QString z;
    z.append(QString("%1").arg(tableWidget->rowCount()));

    setWindowTitle("Great Little Radio Player" + QString(" - ") + z + LangStations);

    ui->FilterLineEdit->setVisible(ui->actionFilter_station_list->isChecked());
    ui->clearButton->setVisible(ui->actionFilter_station_list->isChecked());
    ui->clearButton->setToolTip(ClearFilter);

    readSettings();

    trayIcon = new QSystemTrayIcon(this);
    trayMenu = new QMenu(this);
    SystemTray(ShowStationsSystemTray);


DoAsYouReadSettings();

}
//------------------------------------------------------------------------------------

void MainWindow::Exit()
{
    on_actionSave_stations_triggered();

    close();
    delete ui;
    exit(0);
}

//------------------------------------------------------------------------------------
MainWindow::~MainWindow()
{
    on_actionSave_stations_triggered();
    writeSettings();
    close();
    delete ui;
    exit(0);
}
//------------------------------------------------------------------------------------
void MainWindow::AfterStart()
{
    music->isValid();
    metaInformationResolver = new Phonon::MediaObject(this);
}
//------------------------------------------------------------------------------------
/*void MainWindow::on_actionG_triggered()
{
    AfterStart();
}*/
//------------------------------------------------------------------------------------
void MainWindow::SystemTray(bool ContextMenuIsVisible)
{
    trayIcon->setContextMenu(NULL);
    trayMenu->clear();

        // load icon
            QIcon icon = QIcon(":/images/IMG/radio-tray-white-48.svg");
            trayIcon->setIcon(icon);

            if (ContextMenuIsVisible)
            {
            //Stringlists and populate
            QStringList StationsList;
            QStringList CategoryList;

            for (int i=0;i<tableWidget->rowCount();i++)
                {
                    StationsList << tableWidget->item(i,0)->text();
                    CategoryList << tableWidget->item(i,2)->text();
                }
            StationsList.sort();
            StationsList.removeDuplicates();
            CategoryList.sort();
            CategoryList.removeDuplicates();

            //Build menus
            QFont serifFont;
            serifFont.setBold(true);

            //By Categoryes
            for (int x = 0; x < CategoryList.count(); x++)
            {
                QMenu *Action = new QMenu(trayMenu);
                Action->setTitle(CategoryList.at(x));
                Action->setIcon(QIcon(":/images/IMG/genre.png"));

                for (int i = 0; i<tableWidget->rowCount(); i++)
                    {
                    if (tableWidget->item(i,2)->text() == CategoryList.at(x))
                        {

                        QAction *StationAction = new QAction(Action);
                        if (tableWidget->item(i,4)->text() == "Favorite")
                        {
                        StationAction->setIcon(QIcon(":/images/IMG/note-favorite.png"));
                        StationAction->setFont(serifFont);
                        }
                        else
                           StationAction->setIcon(QIcon(":/images/IMG/note.png"));

                        StationAction->setText(tableWidget->item(i,0)->text());
                        StationAction->setStatusTip(LangThisStationComeFrom);
                        StationAction->setIconVisibleInMenu(true);

                        connect(StationAction, SIGNAL(triggered()), this, SLOT(TrayPlayMusic()));
                        Action->addAction(StationAction);
                        }
                    }
            trayMenu->addMenu(Action);
            }
            trayMenu->addSeparator();

            //By Favorites
            QMenu *FavoriteAction = new QMenu(trayMenu);
            FavoriteAction->setTitle(LangFavorite);
            FavoriteAction->setIcon(QIcon(":/images/IMG/favorite.png"));

                for (int i = 0; i<tableWidget->rowCount(); i++)
                    {
                    if (tableWidget->item(i,4)->text() == "Favorite")
                        {
                        QAction *StationAction = new QAction(FavoriteAction);
                        if (tableWidget->item(i,4)->text() == "Favorite")
                            {
                            StationAction->setIcon(QIcon(":/images/IMG/note-favorite.png"));

                            StationAction->setText(tableWidget->item(i,0)->text());
                            StationAction->setStatusTip(LangThisStationComeFrom);
                            StationAction->setIconVisibleInMenu(true);

                            connect(StationAction, SIGNAL(triggered()), this, SLOT(TrayPlayMusic()));
                            FavoriteAction->addAction(StationAction);
                            }
                        }
                    }
            trayMenu->addSeparator();
            trayMenu->addMenu(FavoriteAction);


            //-----------About--------------------
            trayMenu->addSeparator();
            QMenu *AboutAction = new QMenu(trayMenu);
            AboutAction->setTitle(LangAbout);
            AboutAction->setIcon(QIcon(":/images/IMG/info.png"));
            AboutAction->addAction(ui->actionAbout_program);
            AboutAction->addAction(ui->actionAbout_author);
            trayMenu->addMenu(AboutAction);
            trayMenu->addSeparator();
            }
            //------------------Stop--------------------
            StopMenuItem = new QAction(trayMenu);
            StopMenuItem->setVisible(false);
            StopMenuItem->setIcon(QIcon(":/images/IMG/disconnect.png"));
            trayMenu->addAction(StopMenuItem);
            connect(StopMenuItem, SIGNAL(triggered()), this, SLOT(StopRadioStationButton_clicked()));
            //-----------------Show-------------------------------
            //Show-Hide
            ShowHide = new QAction(trayMenu);
            if (isVisible()) ShowHide->setText(LangHidePlayer);
            else ShowHide->setText(LangShowPlayer);
            ShowHide->setIcon(QIcon(":/images/IMG/hide.png"));
            connect(ShowHide, SIGNAL(triggered()),this, SLOT(ShowMainWindow()));
            trayMenu->addAction(ShowHide);
            //-----------------Close-------------------------------
            //Close
            QAction *Close = new QAction(trayMenu);
            Close->setText(LangExit);
            Close->setIcon(QIcon(":/images/IMG/close.png"));
            connect(Close, SIGNAL(triggered()), this, SLOT(Exit()));
            trayMenu->addAction(Close);
            //---------------Set systray---------------------
            // set up and show the system tray icon

            trayIcon->setContextMenu(trayMenu);
            trayIcon->setToolTip(windowTitle());
            trayIcon->show();
            connect(trayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),this, SLOT(TrayIconActivated(QSystemTrayIcon::ActivationReason)));
}
//------------------------------------------------------------------------------------
void MainWindow::TrayIconActivated(QSystemTrayIcon::ActivationReason razlog)
{
    switch(razlog)
       {
       case QSystemTrayIcon::Trigger:
        {
        ShowMainWindow();
        }
       case QSystemTrayIcon::DoubleClick:
           {
           ShowMainWindow();
           }
       case QSystemTrayIcon::MiddleClick:
           {
           //
           }
       default:
               ;
       }
}
//------------------------------------------------------------------------------------
void MainWindow::ShowMainWindow()
{
    if (!isHidden())
        {
        hide();
        }
    else
        {
        show();
        }

    if (isVisible()) ShowHide->setText(LangHidePlayer);
    else ShowHide->setText(LangShowPlayer);


}
//------------------------------------------------------------------------------------
void MainWindow::SloveIfStationFileNotExists()
{
    //Provera da li postoji fajl sa jezicima i stanicama i ako ne postoji, pravljenje jednog takvog fajla
    PathToStationsDir = QDir::homePath() + "/.config/glrp/";
    PathToStationsFile = PathToStationsDir + "stations.csv";

try
    {
    //Lokalni dir
    QDir D(PathToStationsDir);
    if (!D.exists())
    {

    if (D.mkpath(PathToStationsDir))
        {
        //
        }
        else
            {
            QMessageBox msgBoxDir;
            msgBoxDir.setText(LangError1 + PathToStationsDir + LangError1a);
            msgBoxDir.exec();
            }

    }
    //Lokalni fajl
    QFile F(PathToStationsFile);
    if (!F.exists())
            {

            if (F.copy("/opt/extras.ubuntu.com/glrp/stations.csv",PathToStationsFile))
                {
                //
                }
                else
                    {
                    QMessageBox msgBoxFile;
                    msgBoxFile.setText(LangError2 + PathToStationsFile + LangError1a);
                    msgBoxFile.exec();
                    }

            }

    PathToOrigLanguageDir = "/opt/extras.ubuntu.com/glrp/language/";
    PathToDestLanguageDir = QDir::homePath() + "/.config/glrp/language/";

    QDir LanguageDir(PathToDestLanguageDir);

    //Srpski
    QFile FileSRB(PathToOrigLanguageDir + "Serbian.conf");
    //Hrvatski
    QFile FileCRO(PathToOrigLanguageDir + "Croatian.conf");


    if (!LanguageDir.exists())
        {
        LanguageDir.mkpath(PathToDestLanguageDir);

            if (FileSRB.exists())
                {
                FileSRB.copy(PathToOrigLanguageDir + "Serbian.conf",PathToDestLanguageDir + "Serbian.conf");
                FileCRO.copy(PathToOrigLanguageDir + "Croatian.conf",PathToDestLanguageDir + "Croatian.conf");
                }
        }
        else
        {
        QFile DestFileSRB(PathToDestLanguageDir + "Serbian.conf");
        if (!DestFileSRB.exists())
            {
            FileSRB.copy(PathToOrigLanguageDir + "Serbian.conf",PathToDestLanguageDir + "Serbian.conf");
            FileCRO.copy(PathToOrigLanguageDir + "Croatian.conf",PathToDestLanguageDir + "Croatian.conf");
            }
        }
    }
    catch(...){}
}

//------------------------------------------------------------------------------------
void MainWindow::on_actionSave_stations_triggered()
{
    QFile SaveFile(PathToStationsFile);
    if (SaveFile.exists())
    {
             if(SaveFile.open(QIODevice::WriteOnly))
             {
                 QTextStream ts(&SaveFile);
                 QStringList strList;
                 for( int r = 0; r < tableWidget->rowCount(); ++r )
                    {
                     strList.clear();
                     for( int c = 0; c < tableWidget->columnCount(); ++c )
                        {
                        strList << "\"" + tableWidget->item(r, c)->text() + "\"";
                        }
                    ts << strList.join(",") + "\n";
                    }
                SaveFile.close();
             }
    }
}
//------------------------------------------------------------------------------------
void MainWindow::Load_stations(QString PathToStationsFile)
{
    QFile OpenFile(PathToStationsFile);
    if (OpenFile.exists())
    {
            if(OpenFile.open(QIODevice::ReadOnly))
                {
                QTextStream ts( &OpenFile );
                QList<QStringList> list;
                int row = 0, col = 0;

                while( !ts.atEnd() )
                    {
                    list << ts.readLine().split( "," );
                    }
                OpenFile.close();

                tableWidget->setRowCount( list.count() );
                tableWidget->setColumnCount( list[0].count() );

                tableWidget->setUpdatesEnabled( false );
                foreach( QStringList l, list )
                {
                    foreach( QString str, l )
                    {

                        if( str.endsWith( '"' ) ) str.chop(1);
                        if( str.startsWith( '"' ) ) str.remove(0,1);
                        tableWidget->setItem( row, col++, new QTableWidgetItem( str ));
                    }
                    row++; col=0;
                }
                tableWidget->setUpdatesEnabled( true );
            }
       }
}
//------------------------------------------------------------------------------------
void MainWindow::on_actionAdd_new_station_triggered()
{
    on_actionSave_stations_triggered();
    StopRadioStationButton_clicked();

        AddDialog *D;
        D = new AddDialog(this);
        D->exec();

        if (D->AddCancelTriger)
        {
        AddNewStationFunction(D->StationName, D->StationAddress, D->StationGenre, D->StationCountry);
        }
}

//------------------------------------------------------------------------------------
void MainWindow::RefreshGenreCountryList(QString arg1)
{
        ui->GenreCountryStringTreeWidget->clear();
        ui->GenreCountryStringTreeWidget->setColumnCount(2);
        ui->GenreCountryStringTreeWidget->setColumnWidth(0,180);
        ui->GenreCountryStringTreeWidget->setColumnWidth(1,50);
        ui->GenreCountryStringTreeWidget->header()->hide();

        QStringList GenreCountryStringList;
        GenreCountryStringList.clear();

        int row = tableWidget->rowCount();
        //---------------------------
        for (int n = 0; n < row; n++)
            {
            if (arg1 == "Country")
                {
                GenreCountryStringList << tableWidget->item(n,3)->text();
                }
            else if (arg1 == "Genre")
                {
                GenreCountryStringList << tableWidget->item(n,2)->text();
                }
            }
        GenreCountryStringList.sort();
        GenreCountryStringList.removeDuplicates();
        //---------------------------
        if (arg1 == "Genre")
        {
            //All
            QTreeWidgetItem * AllItem = new QTreeWidgetItem(ui->GenreCountryStringTreeWidget);
            AllItem->setText(0,QString("All Genres"));
            AllItem->setIcon(0,QIcon(":/images/IMG/genre-light.png"));

            QFont font;
            font.setBold(true);
            //font.setPointSize(10);
            AllItem->setFont(0,font);
            //Fin All
        for (int i = 0; i < GenreCountryStringList.count(); i++)
            {
            QTreeWidgetItem * GenreItem = new QTreeWidgetItem(ui->GenreCountryStringTreeWidget);
            GenreItem->setText(0,QString(GenreCountryStringList.at(i)));
            GenreItem->setIcon(0,QIcon(":/images/IMG/genre-light.png"));

            QBrush crna(QColor(0,0,0,200));// crna
            GenreItem->setForeground(0,crna);
            //---------------------------
            QStringList CountryStringList;
            CountryStringList.clear();
            for (int s = 0; s < row; s++)
                {
                if (tableWidget->item(s,2)->text() == QString(GenreCountryStringList.at(i)))
                    {
                    CountryStringList << tableWidget->item(s,3)->text();
                    }
                }
            CountryStringList.sort();
            CountryStringList.removeDuplicates();

            int all_stations_in_category_count = 0;
            for (int l = 0; l < CountryStringList.count(); l++)
                {
                QTreeWidgetItem * StationNameItem = new QTreeWidgetItem(GenreItem);
                StationNameItem->setText(0,CountryStringList.at(l));
                StationNameItem->setIcon(0,QIcon(":/images/IMG/flag22.png"));

                QBrush tamnosiva(QColor(139,139,131,255));//tamnije siva
                StationNameItem->setForeground(0,tamnosiva);
                int stationcount = 0;
                for (int r = 0; r < row; r++)
                    {
                    if (QString(GenreCountryStringList.at(i)) == tableWidget->item(r,2)->text())
                        {
                        if (QString(CountryStringList.at(l)) == tableWidget->item(r,3)->text())
                            {
                            ++stationcount;
                            ++all_stations_in_category_count;
                            }
                        }
                    }
                StationNameItem->setText(1,QString("%1").arg(stationcount));
                StationNameItem->setTextAlignment(1,Qt::AlignRight | Qt::AlignVCenter);
                StationNameItem->setForeground(1,tamnosiva);

                GenreItem->setText(1,QString(QString("%1").arg(all_stations_in_category_count)));
                GenreItem->setTextAlignment(1,Qt::AlignRight | Qt::AlignVCenter);

                QFont Genrefont;
                Genrefont.setBold(true);
                GenreItem->setFont(1,Genrefont);
                QBrush blagosiva(QColor(105,105,105,255));//blago siva
                GenreItem->setForeground(1,blagosiva);
                GenreItem->addChild(StationNameItem);
                }
            }
        }
        //---------------------------
        if (arg1 == "Country")
        {
            //All
            QTreeWidgetItem * AllItem = new QTreeWidgetItem(ui->GenreCountryStringTreeWidget);
            AllItem->setText(0,QString("All Countries"));
            AllItem->setIcon(0,QIcon(":/images/IMG/flag-light.png"));

            QFont font;
            font.setBold(true);
            AllItem->setFont(0,font);
            //Fin All

        for (int i = 0; i < GenreCountryStringList.count(); i++)
            {
            QTreeWidgetItem * GenreItem = new QTreeWidgetItem(ui->GenreCountryStringTreeWidget);
            GenreItem->setText(0,QString(GenreCountryStringList.at(i)));
            GenreItem->setIcon(0,QIcon(":/images/IMG/flag-light.png"));
            QBrush crna(QColor(0,0,0,200));// crna
            GenreItem->setForeground(0,crna);
            //---------------------------
            QStringList GenreStringList;
            GenreStringList.clear();
            for (int s = 0; s < row; s++)
                {
                if (tableWidget->item(s,3)->text() == QString(GenreCountryStringList.at(i)))
                    {

                    GenreStringList << tableWidget->item(s,2)->text();

                    }
                }
            GenreStringList.sort();
            GenreStringList.removeDuplicates();
            int all_stations_in_category_count = 0;
            for (int l = 0; l < GenreStringList.count(); l++)
                {
                QTreeWidgetItem * StationNameItem = new QTreeWidgetItem(GenreItem);
                StationNameItem->setText(0,QString(GenreStringList.at(l)));
                StationNameItem->setIcon(0,QIcon(":/images/IMG/genre22.png"));


                QBrush tamnosiva(QColor(139,139,131,255));//tamnije siva
                StationNameItem->setForeground(0,tamnosiva);


                int stationcount = 0;
                for (int r = 0; r < row; r++)
                    {

                    if (QString(GenreCountryStringList.at(i)) == tableWidget->item(r,3)->text())
                        {
                        if (QString(GenreStringList.at(l)) == tableWidget->item(r,2)->text())
                            {
                            ++stationcount;
                            ++all_stations_in_category_count;
                            }
                        }
                    }
                StationNameItem->setText(1,QString("%1").arg(stationcount));
                StationNameItem->setTextAlignment(1,Qt::AlignRight | Qt::AlignVCenter);
                StationNameItem->setForeground(1,tamnosiva);

                GenreItem->setText(1,QString(QString("%1").arg(all_stations_in_category_count)));
                GenreItem->setTextAlignment(1,Qt::AlignRight | Qt::AlignVCenter);
                QFont Genrefont;
                Genrefont.setBold(true);
                GenreItem->setFont(1,Genrefont);
                QBrush blagosiva(QColor(105,105,105,255));//blago siva
                GenreItem->setForeground(1,blagosiva);
                GenreItem->addChild(StationNameItem);
                }
            }
        }

    ui->StationslistWidget->clear();

    QString z;
    z.append(QString("%1").arg(tableWidget->rowCount()));
    setWindowTitle("Great Little Radio Player" + QString(" - ") + z + LangStations);

    on_actionExpand_Collapse_triggered();
}
//------------------------------------------------------------------------------------
void MainWindow::on_GenreCountryStringTreeWidget_itemClicked(QTreeWidgetItem *item, int column)
{
    ui->StationslistWidget->clear();

        if (item->parent()) //Ukoliko je selektiran neki child item
        {
            if (StatusCountry)
            {
            for (int i = 0; i < tableWidget->rowCount(); i++)
                {
                if ((item->parent()->text(0) == tableWidget->item(i,3)->text()) && item->text(0) == tableWidget->item(i,2)->text())
                    {
                    if (tableWidget->item(i,4)->text() == "Favorite")
                        {
                        QListWidgetItem *itemX;
                        itemX = new QListWidgetItem(QIcon(":/images/IMG/note-favorite.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                        }
                    else
                        {
                        QListWidgetItem *itemX;
                        itemX = new QListWidgetItem(QIcon(":/images/IMG/note.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                        }
                    }
                }
            }
            else if (StatusGenre)
                {
                for (int i = 0; i < tableWidget->rowCount(); i++)
                    {
                    if ((item->parent()->text(0) == tableWidget->item(i,2)->text()) && item->text(0) == tableWidget->item(i,3)->text())
                        {
                        if (tableWidget->item(i,4)->text() == "Favorite")
                            {
                            QListWidgetItem *itemX;
                            itemX = new QListWidgetItem(QIcon(":/images/IMG/note-favorite.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                            }
                        else
                            {
                            QListWidgetItem *itemX;
                            itemX = new QListWidgetItem(QIcon(":/images/IMG/note.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                            }
                        }
                    }
                }
        }
        else //Ukoliko je selektiran neki glavni item
            {
            if ((item->text(0) == "All Countries") || (item->text(0) == "All Genres"))
                {
                for (int i = 0; i < tableWidget->rowCount(); i++)
                    {
                    if (tableWidget->item(i,4)->text() == "Favorite")
                        {
                        QListWidgetItem *itemX;
                        itemX = new QListWidgetItem(QIcon(":/images/IMG/note-favorite.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                        }
                    else
                        {
                        QListWidgetItem *itemX;
                        itemX = new QListWidgetItem(QIcon(":/images/IMG/note.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                        }

                    }
                }
            else
                {
                if (StatusCountry)
                    {
                    for (int i = 0; i < tableWidget->rowCount(); i++)
                        {
                        if (item->text(0) == tableWidget->item(i,3)->text())
                            {
                            if (tableWidget->item(i,4)->text() == "Favorite")
                                {
                                QListWidgetItem *itemX;
                                itemX = new QListWidgetItem(QIcon(":/images/IMG/note-favorite.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                                }
                            else
                                {
                                QListWidgetItem *itemX;
                                itemX = new QListWidgetItem(QIcon(":/images/IMG/note.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                                }
                            }
                        }
                    }
                    else if (StatusGenre)
                        {
                        for (int i = 0; i < tableWidget->rowCount(); i++)
                            {
                            if (item->text(0) == tableWidget->item(i,2)->text())
                                {
                                if (tableWidget->item(i,4)->text() == "Favorite")
                                    {
                                    QListWidgetItem *itemX;
                                    itemX = new QListWidgetItem(QIcon(":/images/IMG/note-favorite.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                                    }
                                else
                                    {
                                    QListWidgetItem *itemX;
                                    itemX = new QListWidgetItem(QIcon(":/images/IMG/note.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                                    }
                                }
                            }
                        }
                }
            }
    ui->StationslistWidget->sortItems(Qt::AscendingOrder);
}
//------------------------------------------------------------------------------------
void MainWindow::on_label_linkActivated(const QString &link)
{
    StopRadioStationButton_clicked();
}
//------------------------------------------------------------------------------------
void MainWindow::ShowContextMenu(const QPoint& pos) // this is a slot
{
    QMenu *menu = new QMenu;

    QString S(LangFavorite + QString(" [on/off]"));
    menu->addAction(S, this, SLOT(SetOrRemoveFavorite()));
    menu->addSeparator();
    menu->addAction(LangDelete, this, SLOT(DeleteStation()));
    menu->exec(ui->StationslistWidget->mapToGlobal(pos));

    on_actionSave_stations_triggered();
}
//------------------------------------------------------------------------------------
void MainWindow::SetOrRemoveFavorite()
{
    try
        {
        QString S(ui->StationslistWidget->selectedItems().takeAt(0)->text());

        for (int i = 0; i < tableWidget->rowCount(); i++)
        {
            if (S == tableWidget->item(i,0)->text())
                {
                if (tableWidget->item(i,4)->text() == "Favorite")
                    {
                    tableWidget->item(i,4)->setText("");
                    ui->StationslistWidget->selectedItems().takeAt(0)->setIcon(QIcon(":/images/IMG/note.png"));
                    }
                else
                    {
                    tableWidget->item(i,4)->setText("Favorite");
                    ui->StationslistWidget->selectedItems().takeAt(0)->setIcon(QIcon(":/images/IMG/note-favorite.png"));
                    }
                break;
                }

        }
        }catch(...){}
}
//------------------------------------------------------------------------------------
void MainWindow::DeleteStation()
{
    QString S(ui->StationslistWidget->selectedItems().takeAt(0)->text());

        QMessageBox msgBox;
        msgBox.setText(LangDeleteInfo1 + "<b>'" + S + "'</b>" + LangDeleteInfo1a);
         msgBox.setInformativeText(LangDeleteInfo1b);
         msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel);
         msgBox.setDefaultButton(QMessageBox::Cancel);
         msgBox.setIcon(QMessageBox::Warning);
         int ret = msgBox.exec();

         switch (ret) {
           case QMessageBox::Yes:
                {
                    try
                    {
                    for (int i = 0; i < tableWidget->rowCount(); i++)
                    {
                         if (S == tableWidget->item(i,0)->text())
                             {
                             tableWidget->removeRow(i);
                             //Osvezi klikom na neko dugme
                             RefreshGenreCountryList("Genre");
                             on_actionList_all_Favorites_triggered();
                             break;
                             }
                     }
                     }catch(...){}
                }
               break;
           case QMessageBox::No:
               {
                 QMessageBox msgBox1;
                 msgBox1.setText(LangDeleteInfo2);
                 msgBox1.setInformativeText(LangDeleteInfo2a + "<b>'" + S + "'</b>" + LangDeleteInfo2b);
                 msgBox1.setStandardButtons(QMessageBox::Ok);
                 msgBox1.setDefaultButton(QMessageBox::Ok);
                 msgBox1.setIcon(QMessageBox::Information);
                 msgBox1.exec();
                }
               break;
           case QMessageBox::Cancel:
               break;
           default:
               break;
         }
}
//------------------------------------------------------------------------------------
void MainWindow::TrayPlayMusic()
{
        QAction *A;
        QObject *Y = QObject::sender();
        A = qobject_cast<QAction *>(Y);
        QString StationName(A->text());

        try
        {
        QString S(StationName);

        for (int i = 0; i < tableWidget->rowCount(); i++)
        {
            if (S == tableWidget->item(i,0)->text())
                {
                PlayName = tableWidget->item(i,0)->text();
                PlayAddress = tableWidget->item(i,1)->text();
                PlayCountry = tableWidget->item(i,3)->text();
                PlayGenre = tableWidget->item(i,2)->text();
                PlayFavorite = tableWidget->item(i,4)->text();
                break;
                }
        }
        PlayMusic(PlayName,PlayAddress);
        StopMenuItem->setText(LangStopStation + PlayName + "'");
        StopMenuItem->setVisible(true);
        CheckIfStationRunning();

        ui->widget->show();



        }catch(...){}
}

//------------------------------------------------------------------------------------
void MainWindow::on_actionAbout_program_triggered()
{
    QString z;
    z.append(QString("%1").arg(tableWidget->rowCount()));

    show();
    QMessageBox reactMsgBox;
    reactMsgBox.setWindowTitle(LangAboutProgram1);
    reactMsgBox.setWindowIcon(QIcon(":/images/IMG/radio-tray-white-48.svg"));
    reactMsgBox.setText("<font size=4>" + LangAboutProgram1a + "Great Little Radio Player 1.3.0</font>");
    reactMsgBox.setInformativeText(QString("<table width='100%' border='0'><tr><td align='center' width='15%'><img src='" + QString(":/images/IMG/radio128.png'/><br>")) + "</td><td align='justify' width='85%'>" + LangAboutProgram1b + z + "<br><br><PLAINTEXT>Copyright: 2012 Dejan Petrovic dekiseka.petrovic@gmail.com<br>License: GPL-3.0+</PLAINTEXT></td></tr></table>");
    reactMsgBox.exec();
}
//------------------------------------------------------------------------------------
void MainWindow::on_What_you_should_know_triggered()
{
    show();
    QMessageBox reactMsgBox;
    reactMsgBox.setWindowTitle(LangWhatYouShouldKnow1);
    reactMsgBox.setWindowIcon(QIcon(":/images/IMG/radio-tray-white-48.svg"));
    reactMsgBox.setText("<font size=4>" + LangWhatYouShouldKnow1a + "Great Little Radio Player 1.3.0" + "</font>");
    reactMsgBox.setInformativeText(QString("<table width='100%' border='0'><tr><td align='center' width='15%'><img src='" + QString(":/images/IMG/radio128.png'/>")) + QString("</td><td><ul><li>") + LangWhatYouShouldKnow1b + QString("</td></tr></table><br><br>") + LangEnjoy);
    reactMsgBox.exec();
}
//------------------------------------------------------------------------------------
void MainWindow::on_actionAbout_author_triggered()
{
    show();
    QMessageBox reactMsgBox;
    reactMsgBox.setWindowTitle(LangAboutAuthor1);
    reactMsgBox.setWindowIcon(QIcon(":/images/IMG/radio-tray-white-48.svg"));
    reactMsgBox.setText("<font size=4>" + LangAboutAuthor1a + "Great Little Radio Player 1.3.0</font>");
    reactMsgBox.setInformativeText(QString("<table width='100%' border='0'><tr><td align='center' width='15%'><img src='" + QString(":/images/IMG/radio128.png'/>")) + "</td><td valign='middle' width='85%'>" + "Dejan Petrovic<br>dekiseka.petrovic@gmail.com</td></tr></table>");
    reactMsgBox.exec();
}
//------------------------------------------------------------------------------------
void MainWindow::on_actionWhat_s_new_triggered()
{
    show();
    QMessageBox reactMsgBox;
    reactMsgBox.setWindowTitle(LangWhatsNew1);
    reactMsgBox.setWindowIcon(QIcon(":/images/IMG/radio-tray-white-48.svg"));
    reactMsgBox.setText("<font size=4>" + LangWhatsNew1a + "</font>");
    reactMsgBox.setInformativeText(QString("<table width='100%' border='0'><tr><td align='center' width='15%'><img src='" + QString(":/images/IMG/radio128.png'/>")) + "</td><td valign='justify' width='85%'>" + LangWhatsNew1b + "</td></tr></table><br><br>" + LangEnjoy);
    reactMsgBox.exec();
}
//------------------------------------------------------------------------------------
void MainWindow::on_actionHow_can_you_help_triggered()
{
    show();
    QMessageBox reactMsgBox;
    reactMsgBox.setWindowTitle(LangHowCanYouHelp1);
    reactMsgBox.setWindowIcon(QIcon(":/images/IMG/radio-tray-white-48.svg"));
    reactMsgBox.setText("<font size=4>" + LangHowCanYouHelp1a + "</font>");
    reactMsgBox.setInformativeText(QString("<table width='100%' border='0'><tr><td align='center' width='15%'><img src='" + QString(":/images/IMG/radio128.png'/>")) + "</td><td valign='justify' width='85%'>" + LangHowCanYouHelp1b + "</td></tr></table><br><br>" + LangEnjoy + "<br><font color='#6699CC'>dekiseka.petrovic@gmail.com</font>");
    reactMsgBox.exec();
}
//------------------------------------------------------------------------------------

void MainWindow::AddNewStationFunction(QString StationName, QString StationAddress, QString StationGenre, QString StationCountry)
{
    if ((!StationName.isEmpty()) && (!StationAddress.isEmpty()) && (!StationGenre.isEmpty()) && (!StationCountry.isEmpty()))
        {
            try
            {
            int row = tableWidget->rowCount();
            tableWidget->insertRow(row);

            QTableWidgetItem *Name = new QTableWidgetItem;
            Name->setText(StationName);

            QTableWidgetItem *Address = new QTableWidgetItem;
            Address->setText(StationAddress);

            QTableWidgetItem *Genre = new QTableWidgetItem;
            Genre->setText(StationGenre);

            QTableWidgetItem *Country = new QTableWidgetItem;
            Country->setText(StationCountry);

            QTableWidgetItem *Favorite = new QTableWidgetItem;
            Favorite->setText("");

            QTableWidgetItem *Item5 = new QTableWidgetItem;
            Item5->setText("");

            QTableWidgetItem *Item6 = new QTableWidgetItem;
            Item6->setText("");

            tableWidget->setItem(row, 0, Name);
            tableWidget->setItem(row, 1, Address);
            tableWidget->setItem(row, 2, Genre);
            tableWidget->setItem(row, 3, Country);
            tableWidget->setItem(row, 4, Favorite);
            tableWidget->setItem(row, 5, Item5);
            tableWidget->setItem(row, 6, Item6);

            QMessageBox reactMsgBox;
            reactMsgBox.setText(LangStationSaved1);
            QString s(StationAddress);
            QString startaddress(s.mid(0,15));
            reactMsgBox.setInformativeText(SName + "\t" + StationName + "\n" + SAddress + "\t" + startaddress + "..." + "\n\n" + LangStationSaved1a);
            reactMsgBox.setIcon(QMessageBox::Information);
            reactMsgBox.exec();
            }
            catch(...){}
        }
        if (StatusCountry)
            RefreshGenreCountryList("Country");
        else if (StatusGenre)
            RefreshGenreCountryList("Genre");

        SystemTray(ShowStationsSystemTray);
}
//------------------------------------------------------------------------------------
void MainWindow::StopRadioStationButton_clicked()
{
       music->stop();

       ui->widget->hide();
       MainTimer->stop();
       CheckIfStationRunning();
       StopMenuItem->setVisible(false);
}
//------------------------------------------------------------------------------------
void MainWindow::on_StationslistWidget_itemClicked(QListWidgetItem *item)
{
    try
        {
        QString S(item->text());

        for (int i = 0; i < tableWidget->rowCount(); i++)
        {
            if (S == tableWidget->item(i,0)->text())
                {
                PlayName = tableWidget->item(i,0)->text();
                PlayAddress = tableWidget->item(i,1)->text();
                PlayCountry = tableWidget->item(i,3)->text();
                PlayGenre = tableWidget->item(i,2)->text();
                PlayFavorite = tableWidget->item(i,4)->text();
                break;
                }
        }
        PlayMusic(PlayName,PlayAddress);
        StopMenuItem->setText("Stop '" + PlayName + "'");
        StopMenuItem->setVisible(true);
        CheckIfStationRunning();

        ui->widget->show();
        }catch(...){}
}
//------------------------------------------------------------------------------------
void MainWindow::PlayMusic(QString StationName, QString StationAddress)
{
    Phonon::BackendCapabilities::availableAudioOutputDevices();
    try
    {
    music->setCurrentSource(Phonon::MediaSource(StationAddress));
    music->play();
    MainTimer->start(1000);
    }catch(...){}

    if ((trayIcon->supportsMessages()) && (ShowSystemTrayMessage))
    {
        trayIcon->showMessage("Great Little Radio Player", StationName, QSystemTrayIcon::NoIcon,2000);
    }
}
//------------------------------------------------------------------------------------
void MainWindow::CheckIfStationRunning()
{
    IMGLabel_StatusString.clear();
    QString z;
    z.append(QString("%1").arg(tableWidget->rowCount()));
    QString TITLE;
    QIcon icon;
    QString IsFavoriteIcon;
    if(PlayFavorite == "Favorite") IsFavoriteIcon = QString("<img src='" + QString(":/images/IMG/is-favorite.png'/> "));
    else IsFavoriteIcon = QString("<img src='" + QString(":/images/IMG/not-favorite.png'/> "));

        if (music->state() == Phonon::PlayingState)
            {
            TITLE = QString("Great Little Radio Player") + QString(" - ") + z + LangStations + QString(" - Playing: " + PlayName);
            StationNameStatusFont = QString("<font color=#1589FF size=5>");
            IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-tray-blue-48-wide.svg'/>"));
            icon = QIcon(":/images/IMG/radio-tray-blue-48.svg");
            }
        else if (music->state() == Phonon::StoppedState)
            {
            TITLE = QString("Great Little Radio Player") + QString(" - ") + z + LangStations;
            StationNameStatusFont = QString("<font color=grey size=5>");
            IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-tray-white-48-wide.svg'/>"));
            icon = QIcon(":/images/IMG/radio-tray-white-48.svg");
            }
        else if (music->state() == Phonon::LoadingState)
            {
            TITLE = QString("Great Little Radio Player") + QString(" - ") + z + LangStations;
            StationNameStatusFont = QString("<font color='#99FF00' size=5>");
            IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-tray-green-48-wide.svg'/>"));
            icon = QIcon(":/images/IMG/radio-tray-green-48.svg");
            }
        else if (music->state() == Phonon::ErrorState)
            {
            TITLE = QString("Great Little Radio Player") + QString(" - ") + z + LangStations;
            StationNameStatusFont = QString("<font color='#CC3300' size=5>");
            IMGLabel_StatusString = QString("<img src='" + QString(":/images/IMG/radio-tray-white-48-wide.svg'/>"));
            icon = QIcon(":/images/IMG/radio-tray-white-48.svg");
            }

    StationLabelString = "<font size=1 color=grey><tt>" + LangFrom + PlayCountry + "; " + LangGenre + PlayGenre + "</tt></font>";

    try
    {
    setWindowTitle(TITLE);
    trayIcon->setToolTip(TITLE);
    trayIcon->setIcon(icon);
    ui->label->setText(StationNameStatusFont + IsFavoriteIcon + QString(PlayName) + "<br>" + StationLabelString);
    ui->IMGLabel->setText(IMGLabel_StatusString);
    ui->StopButton->setToolTip(LangStopStation + "'" + PlayName + "'");
    setWindowIcon(icon);
    }
    catch(...){}
}
//------------------------------------------------------------------------------------
void MainWindow::on_StopButton_clicked()
{
    StopRadioStationButton_clicked();
}
//------------------------------------------------------------------------------------
void MainWindow::on_actionSort_stations_by_Country_triggered()
{
    RefreshGenreCountryList("Country");
    StatusGenre = false;
    StatusCountry = true;
}
//------------------------------------------------------------------------------------
void MainWindow::on_actionSort_stations_by_Genre_triggered()
{
    RefreshGenreCountryList("Genre");
    StatusCountry = false;
    StatusGenre = true;
}
//------------------------------------------------------------------------------------
void MainWindow::on_actionList_all_Favorites_triggered()
{
    ui->StationslistWidget->clear();

        for (int i = 0; i < tableWidget->rowCount(); i++)
            {
            if (tableWidget->item(i,4)->text() == "Favorite")
                {
                QListWidgetItem *itemX;
                itemX = new QListWidgetItem(QIcon(":/images/IMG/note-favorite.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                }
            }
}
//------------------------------------------------------------------------------------
void MainWindow::on_actionHide_player_triggered()
{
    SystemTray(ShowStationsSystemTray);

    if (!isHidden())
        {
            hide();
        }
    else
        {
        show();
        }
    //Postavljanje statusa vidljivosti u meni za prikazivanje tj sakrivanje playera
    if (isVisible()) ShowHide->setText(LangHidePlayer);
    else ShowHide->setText(LangShowPlayer);

}
//------------------------------------------------------------------------------------

void MainWindow::on_actionFilter_station_list_triggered()
{
ui->FilterLineEdit->setVisible(ui->actionFilter_station_list->isChecked());
ui->clearButton->setVisible(ui->actionFilter_station_list->isChecked());

if (ui->FilterLineEdit->isVisible())
        {
        FilterList.clear();
        ui->FilterLineEdit->clear();
        ui->StationslistWidget->clear();
        for (int i = 0; i < tableWidget->rowCount(); i++)
            {
            if (tableWidget->item(i,4)->text() == "Favorite")
                {
                QListWidgetItem *itemX;
                itemX = new QListWidgetItem(QIcon(":/images/IMG/note-favorite.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                }
            else
                {
                QListWidgetItem *itemX;
                itemX = new QListWidgetItem(QIcon(":/images/IMG/note.png"), tableWidget->item(i,0)->text(), ui->StationslistWidget, QListWidgetItem::UserType);
                }
            FilterList << tableWidget->item(i,0)->text();
            }
        FilterList.sort();
        ui->FilterLineEdit->setPlaceholderText(LangTypeStationNameHere);

        }
}
//------------------------------------------------------------------------------------

void MainWindow::on_FilterLineEdit_textChanged(const QString &arg1)
{
    QRegExp FilterRegExp(arg1, Qt::CaseInsensitive, QRegExp::Wildcard);
    ui->StationslistWidget->clear();
    ui->StationslistWidget->addItems(FilterList.filter(FilterRegExp));
    for (int i = 0; i < ui->StationslistWidget->count(); i++)
            {
            ui->StationslistWidget->item(i)->setIcon(QIcon(":/images/IMG/note.png"));
            }
}
//------------------------------------------------------------------------------------

void MainWindow::on_clearButton_clicked()
{
    ui->FilterLineEdit->clear();
}
//------------------------------------------------------------------------------------

void MainWindow::on_actionSettings_triggered()
{
    Settings *S;
    S = new Settings(this);

    if (S->exec())
    {
    HideAppCheckBox = S->HideAppCheckBox;
    PlayStationRadioButton = S->PlayStationRadioButton;
    PlayThisStationComboBox = S->PlayThisStationComboBox;
    PlayLastStationRadioButton = S->PlayLastStationRadioButton;
    PlayStationAutomaticly = S->PlayStationAutomaticly;
    ShowStationsSystemTray = S->ShowStationsSystemTray;
    ShowSystemTrayMessage = S->ShowSystemTrayMessage;
    UILanguage = S->UILanguage;
    }

    writeSettings();
}
//------------------------------------------------------------------------------------

void MainWindow::writeSettings()
{
    QSettings settings("glrp", "Great Little Radio Player");
    settings.beginGroup("MainWindow");
    settings.setValue("size", size());
    settings.setValue("pos", pos());
    settings.endGroup();
    settings.beginGroup("OtherSettings");
    settings.setValue("HideApp", HideAppCheckBox);
    settings.setValue("PlayAutomaticly", PlayStationAutomaticly);
    settings.setValue("PlayStation", PlayStationRadioButton);
    settings.setValue("PlayThisStation", PlayThisStationComboBox);
    settings.setValue("PlayLastStation", PlayLastStationRadioButton);
    if (PlayName != "") //Ne zelimo da se zapise da nije pustano nista, jer ranije je ipak nesto pustano i to treba da ostane
    settings.setValue("LastStationName", PlayName);//Zato sto je PlayName upravo ta stanica koja je zadnje pustana
    settings.setValue("ShowStationsSystemTray", ShowStationsSystemTray);
    settings.setValue("ShowBaloonMessages", ShowSystemTrayMessage);
    settings.setValue("UILanguage", UILanguage);
    settings.endGroup();

}
//------------------------------------------------------------------------------------

void MainWindow::readSettings()
{
    QSettings settings("glrp", "Great Little Radio Player");
    settings.beginGroup("MainWindow");
    resize(settings.value("size", QSize(700, 430)).toSize());
    move(settings.value("pos", QPoint(200, 200)).toPoint());
    settings.endGroup();

    settings.beginGroup("OtherSettings");
    HideAppCheckBox = settings.value("HideApp", false).toBool();
    PlayStationAutomaticly = settings.value("PlayAutomaticly", false).toBool();
    PlayStationRadioButton = settings.value("PlayStation", false).toBool();
    PlayThisStationComboBox = settings.value("PlayThisStation", "").toString();
    PlayLastStationRadioButton = settings.value("PlayLastStation", true).toBool();
    LastStationName = settings.value("LastStationName", "").toString();
    ShowStationsSystemTray = settings.value("ShowStationsSystemTray", false).toBool();
    ShowSystemTrayMessage = settings.value("ShowBaloonMessages", true).toBool();
    UILanguage = settings.value("UILanguage", "English").toString();
    settings.endGroup();
}
//------------------------------------------------------------------------------------
void MainWindow::DoAsYouReadSettings()
{
//Show/Hide app
if (HideAppCheckBox) hide();
else show();
//---END---

if (PlayStationAutomaticly)
{
//PlayStation
QString S;
if (PlayStationRadioButton)
    {
    S = PlayThisStationComboBox;
    }
    else if (PlayLastStationRadioButton)
        {
        S = LastStationName;
        }

if (S != "")
{
//PlayAfterStartup
try
    {
    for (int i = 0; i < tableWidget->rowCount(); i++)
    {
        if (S == tableWidget->item(i,0)->text())
            {
            PlayName = tableWidget->item(i,0)->text();
            PlayAddress = tableWidget->item(i,1)->text();
            PlayCountry = tableWidget->item(i,3)->text();
            PlayGenre = tableWidget->item(i,2)->text();
            PlayFavorite = tableWidget->item(i,4)->text();
            break;
            }
    }
    PlayMusic(PlayName,PlayAddress);
    StopMenuItem->setText(LangStopStation + "'" + PlayName + "'");
    StopMenuItem->setVisible(true);
    CheckIfStationRunning();

    ui->widget->show();
    }catch(...){}
}
//---END---
//---END---
}

//Postavljanje statusa vidljivosti u meni za prikazivanje tj sakrivanje playera
if (isVisible()) ShowHide->setText(LangHidePlayer);
else ShowHide->setText(LangShowPlayer);
}

//------------------------------------------------------------------------------------
void MainWindow::on_actionExpand_Collapse_triggered()
{
    if (ui->actionExpand_Collapse->isChecked())
    ui->GenreCountryStringTreeWidget->expandAll();
    else
    ui->GenreCountryStringTreeWidget->collapseAll();
}

//------------------------------------------------------------------------------------
void MainWindow::ReadLanguage(QString Language)
{
    //Language Settings - MainWindow
    QSettings LangSettings("/glrp/language", Language);


    LangSettings.beginGroup("MainWindow");
    LangStations = LangSettings.value("LangStations", " stations").toString();
    LangThisStationComeFrom = LangSettings.value("LangThisStationComeFrom", "This station come from: ").toString();
    LangHidePlayer = LangSettings.value("LangHidePlayer", "Hide player").toString();
    LangShowPlayer = LangSettings.value("LangShowPlayer", "Show player").toString();
    LangExit = LangSettings.value("LangExit", "Exit").toString();
    LangError1 = LangSettings.value("LangError1", "ERROR! We did not made local 'Great Little Radio Player' path: ").toString();
    LangError1a = LangSettings.value("LangError1a", ". Sorry!").toString();
    LangError2 = LangSettings.value("LangError2", "ERROR! We did not set local glrp station file: ").toString();
    LangAbout = LangSettings.value("LangAbout", "About").toString();
    LangFavorite = LangSettings.value("LangFavorite", "Favorite").toString();
    LangDelete = LangSettings.value("LangDelete", "Delete").toString();
    LangDeleteInfo1 = LangSettings.value("LangDeleteInfo1", "Radio station ").toString();
    LangDeleteInfo1a = LangSettings.value("LangDeleteInfo1a", " will be deleted.").toString();
    LangDeleteInfo1b= LangSettings.value("LangDeleteInfo1b", "If you choose YES, there is no turning back! The station will be permanently removed from local resource on your computer, that will not affect on other users.<br>Do you really want to do that?").toString();
    LangDeleteInfo2 = LangSettings.value("LangDeleteInfo2", "Clever!").toString();
    LangDeleteInfo2a = LangSettings.value("LangDeleteInfo2a", "You deside to keep ").toString();
    LangDeleteInfo2b = LangSettings.value("LangDeleteInfo2b", " station.").toString();
    LangStopStation = LangSettings.value("LangStopStation", "Stop '").toString();

    LangAboutProgram1 = LangSettings.value("LangAboutProgram1", "About program").toString();
    LangAboutProgram1a = LangSettings.value("LangAboutProgram1a", "About ").toString();
    LangAboutProgram1b = LangSettings.value("LangAboutProgram1b", "A robust internet radio station streamer. It connects to web sites offering radio streaming and lets you play radio stations directly from that locations. Current stations collection: ").toString();

    LangWhatYouShouldKnow1 = LangSettings.value("LangWhatYouShouldKnow1", "What you should know").toString();
    LangWhatYouShouldKnow1a = LangSettings.value("LangWhatYouShouldKnow1a", "What you should know about ").toString();
    LangWhatYouShouldKnow1b = LangSettings.value("LangWhatYouShouldKnow1b", "The internet radio station collection is large, but that is not the most important thing with a program like this. You can have a lot of fun using Great Little Radio Player even with just a few stations.</li><li>Sometimes when you want to listen to a station, you may experience some problems. It may happen that fully valid internet radio address will not work because of poor internet connection, quirks of the net or some cosmic reason. Be patient and try the same station again a while later.</li><li>When you click on a radio station, wait a few seconds for connection to be established. Sometimes there are several internet servers between you and chosen radio station.</li><li>Some internet radio stations have stated their music category, and we used that information to categorize our collection. However, do not take it as absolutely precise, because it is not.</li></ul>").toString();

    LangAboutAuthor1 = LangSettings.value("LangAboutAuthor1", "About author").toString();
    LangAboutAuthor1a = LangSettings.value("LangAboutAuthor1a", "About author of ").toString();

    LangWhatsNew1 = LangSettings.value("LangWhatsNew1", "What's new...").toString();
    LangWhatsNew1a = LangSettings.value("LangWhatsNew1a", "What's new from last version?").toString();
    LangWhatsNew1b = LangSettings.value("LangWhatsNew1b", "<ul><li>Some bugs are fixed.</li><li>Some part of the interface are simpler. No too many details.</li><li>Station collection is larger.</li><li>Settings dialog is added.</li><li>Expanding and Collapsing of genre/country list</li><li>Playing station in autostart is new option.</li><li>New icons are simplear.</li><li>UI on more languages.</li></ul>").toString();

    LangHowCanYouHelp1 = LangSettings.value("LangHowCanYouHelp1", "How can you help").toString();
    LangHowCanYouHelp1a = LangSettings.value("LangHowCanYouHelp1a", "How can you help?").toString();
    LangHowCanYouHelp1b = LangSettings.value("LangHowCanYouHelp1b", "<ul><li>Send us ideas and suggestions.</li><li>Send us checked internet radio stations and make our station collection bigger.</li><li>Talk about this application and recommend it to others.</li><li>Send us why you like 'Great Little Radio Player', if you do.</li></ul>").toString();

    LangStationSaved1 = LangSettings.value("LangStationSaved1", "Congratulation, station is saved!").toString();
    LangStationSaved1a = LangSettings.value("LangStationSaved1a", "Now you can choose it from the station list!").toString();
    LangFrom = LangSettings.value("LangFrom", "From: ").toString();
    LangGenre = LangSettings.value("LangGenre", "Genre: ").toString();

    LangTypeStationNameHere = LangSettings.value("LangTypeStationNameHere", "Type station name here!").toString();
    ClearFilter = LangSettings.value("ClearFilter","Clear filter").toString();

    LangActionTipsAddNewStation = LangSettings.value("LangActionTipsAddNewStation", "Add new station").toString();
    LangActionTipsSortByCountry = LangSettings.value("LangActionTipsSortByCountry", "Sort by Country").toString();
    LangActionTipsSortByGenre = LangSettings.value("LangActionTipsSortByGenre", "Sort by Genre").toString();
    LangActionTipsExpandColapse = LangSettings.value("LangActionTipsExpandColapse", "Expand/Collapse").toString();
    LangActionTipsShowAllFavorites = LangSettings.value("LangActionTipsShowAllFavorites", "Show all Favorites").toString();
    LangActionTipsShowHideFilter = LangSettings.value("LangActionTipsShowHideFilter", "Show/Hide Filter Stations").toString();
    LangActionTipsShowSettings = LangSettings.value("LangActionTipsShowSettings", "Settings").toString();


    LangEnjoy = LangSettings.value("LangEnjoy", "Enjoy listening radio stations with 'Great Little Radio Player'.").toString();


    //Translate Actions
    //Stations
    ui->menuStations->setTitle(LangSettings.value("LangMenuStations", "Stations").toString());
    ui->actionAdd_new_station->setText(LangActionTipsAddNewStation);
    ui->actionAdd_new_station->setToolTip(LangActionTipsAddNewStation);
    ui->actionHide_player->setText(LangHidePlayer);
    ui->actionHide_player->setToolTip(LangHidePlayer);

    //View
    ui->menuView->setTitle(LangSettings.value("LangMenuView", "View").toString());
    ui->actionSort_stations_by_Country->setText(LangActionTipsSortByCountry);
     ui->actionSort_stations_by_Country->setToolTip(LangActionTipsSortByCountry);
    ui->actionSort_stations_by_Genre->setText(LangActionTipsSortByGenre);
     ui->actionSort_stations_by_Genre->setToolTip(LangActionTipsSortByGenre);
    ui->actionExpand_Collapse->setText(LangActionTipsExpandColapse);
     ui->actionExpand_Collapse->setToolTip(LangActionTipsExpandColapse);
    ui->actionList_all_Favorites->setText(LangActionTipsShowAllFavorites);
     ui->actionList_all_Favorites->setToolTip(LangActionTipsShowAllFavorites);
    ui->actionFilter_station_list->setText(LangActionTipsShowHideFilter);
     ui->actionFilter_station_list->setToolTip(LangActionTipsShowHideFilter);
    ui->actionSettings->setText(LangActionTipsShowSettings);
     ui->actionSettings->setToolTip(LangActionTipsShowSettings);

    //Info
    ui->menuAbout->setTitle(LangSettings.value("LangMenuInfo", "Info").toString());
    ui->What_you_should_know->setText(LangWhatYouShouldKnow1);
    ui->What_you_should_know->setToolTip(LangWhatYouShouldKnow1);
    ui->actionWhat_s_new->setText(LangWhatsNew1);
    ui->actionWhat_s_new->setToolTip(LangWhatsNew1);
    ui->actionHow_can_you_help->setText(LangHowCanYouHelp1);
    ui->actionHow_can_you_help->setToolTip(LangHowCanYouHelp1);
    ui->actionAbout_program->setText(LangAboutProgram1);
    ui->actionAbout_program->setToolTip(LangAboutProgram1);
    ui->actionAbout_author->setText(LangAboutAuthor1);
    ui->actionAbout_author->setToolTip(LangAboutAuthor1);

    LangSettings.endGroup();

    LangSettings.beginGroup("AddNewStation");
    SName = LangSettings.value("SName","Name: ").toString();
    SAddress = LangSettings.value("SAddress","Address: ").toString();
    SGenre = LangSettings.value("SGenre","Genre: ").toString();
    SRegion = LangSettings.value("SRegion","Country/Region: ").toString();

    CancelButtonText = LangSettings.value("CancelButtonText","Cancel").toString();
    AddButtonText = LangSettings.value("AddButtonText","Add").toString();
    ResetButtonText = LangSettings.value("ResetButtonText","Reset").toString();


    LangSettings.endGroup();
}
