#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QSystemTrayIcon>
#include "QTreeWidgetItem"
#include "QListWidgetItem"
#include <QSortFilterProxyModel>
#include <QStandardItemModel>

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    //Settings variable
    bool HideAppCheckBox;
    bool  PlayStationRadioButton;
    QString PlayThisStationComboBox;
    bool PlayLastStationRadioButton;
    QString LastStationName;
    bool PlayStationAutomaticly;
    bool ShowStationsSystemTray;
    bool ShowSystemTrayMessage;
    QString UILanguage;

    //Language Settings - MainWindow
    QString LangStations;
    QString LangThisStationComeFrom;
    QString LangHidePlayer;
    QString LangShowPlayer;
    QString LangExit;
    QString LangError1;
    QString LangError1a;
    QString LangError2;
    QString LangAbout;
    QString LangFavorite;
    QString LangDelete;
    QString LangDeleteInfo1;
    QString LangDeleteInfo1a;
    QString LangDeleteInfo1b;
    QString LangDeleteInfo2;
    QString LangDeleteInfo2a;
    QString LangDeleteInfo2b;
    QString LangStopStation;
    QString LangAboutProgram1;
    QString LangAboutProgram1a;
    QString LangAboutProgram1b;
    QString LangWhatYouShouldKnow1;
    QString LangWhatYouShouldKnow1a;
    QString LangWhatYouShouldKnow1b;

    QString LangAboutAuthor1;
    QString LangAboutAuthor1a;
    QString LangAboutAuthor1b;
    QString LangWhatsNew1;
    QString LangWhatsNew1a;
    QString LangWhatsNew1b;

    QString LangHowCanYouHelp1;
    QString LangHowCanYouHelp1a;
    QString LangHowCanYouHelp1b;

    QString LangStationSaved1;
    QString LangStationSaved1a;
    QString LangFrom;
    QString LangGenre;
    QString LangTypeStationNameHere;
    QString LangActionTipsAddNewStation;
    QString LangActionTipsSortByCountry;
    QString LangActionTipsSortByGenre;
    QString LangActionTipsExpandColapse;
    QString LangActionTipsShowAllFavorites;
    QString LangActionTipsShowHideFilter;
    QString LangActionTipsShowSettings;
    QString SName;
    QString SAddress;
    QString SGenre;
    QString SRegion;
    QString ClearFilter;
    QString CancelButtonText;
    QString AddButtonText;
    QString ResetButtonText;

    QString LangEnjoy;

    ~MainWindow();

private slots:
        void SystemTray(bool ContextMenuIsVisible);

        void TrayIconActivated(QSystemTrayIcon::ActivationReason razlog);

        void on_actionSave_stations_triggered();

        void Load_stations(QString PathToStationsFile);

        void SloveIfStationFileNotExists();

        void on_actionAdd_new_station_triggered();

        void Exit();

        void RefreshGenreCountryList(QString arg1);

        void on_GenreCountryStringTreeWidget_itemClicked(QTreeWidgetItem *item, int column);

        void on_StationslistWidget_itemClicked(QListWidgetItem *item);

        void AddNewStationFunction(QString StationName, QString StationAddress, QString StationGenre, QString StationCountry);

        void StopRadioStationButton_clicked();

        void CheckIfStationRunning();

        void on_actionAbout_program_triggered();

        void on_actionAbout_author_triggered();

        void on_What_you_should_know_triggered();

        void on_label_linkActivated(const QString &link);

        void ShowContextMenu(const QPoint& pos);

        void SetOrRemoveFavorite();

        void DeleteStation();

        void TrayPlayMusic();

        void AfterStart();

        //void on_actionG_triggered();

        void ShowMainWindow();

        void on_StopButton_clicked();

        void on_actionSort_stations_by_Country_triggered();

        void on_actionSort_stations_by_Genre_triggered();

        void on_actionList_all_Favorites_triggered();

        void on_actionHide_player_triggered();

        void on_actionFilter_station_list_triggered();

        void on_FilterLineEdit_textChanged(const QString &arg1);

        void on_clearButton_clicked();

        void on_actionWhat_s_new_triggered();

        void on_actionHow_can_you_help_triggered();

        void on_actionSettings_triggered();

        void writeSettings();

        void readSettings();

        void DoAsYouReadSettings();

        void on_actionExpand_Collapse_triggered();

        void ReadLanguage(QString Language);


private:
        Ui::MainWindow *ui;

        void PlayMusic(QString StationName, QString StationAddress);
        void FilterStations(QString GenreCountry, QString SelectedItem);
        int m_alpha;

        QAction *minimizeAction;
        QAction *maximizeAction;
        QAction *restoreAction;
        QAction *quitAction;
        QSystemTrayIcon *trayIcon;
        QMenu *trayMenu;

};

#endif // MAINWINDOW_H
