#include "settings.h"
#include "ui_settings.h"
#include "mainwindow.h"
#include <QSettings>
#include <QtCore/QFile>
#include <QDir>
#include "QTableWidgetItem"
#include <QTextStream>
#include "QPushButton"

QTableWidget *TestTableWidget3;
QString PathToStationsDir3;
QString PathToStationsFile3;

Settings::Settings(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::Settings)
{
    ui->setupUi(this);

    QSettings temp_settings("glrp", "Great Little Radio Player");
    temp_settings.beginGroup("OtherSettings");
    ReadLanguage(temp_settings.value("UILanguage", "English").toString());
    temp_settings.endGroup();

    QString Image("<img src=':/images/IMG/settings.png'/>");
    ui->MainLabel1->setText("<table><tr><td align=center width='70'>" + QString(Image) + "</td><td align=justify><font size=4>" + LangSettingsTitle + "</font><br>" + QString(LangSettingsInfo) + "</td></tr></table>");
    setWindowTitle(LangSettingsTitle);

    LoadStationsToAutoPlayList();
    readSettings();
    ui->buttonBox->setCenterButtons(true);
    ui->buttonBox->clear();

    QPushButton *findButton = new QPushButton(OKButtonText);
    findButton->setDefault(true);
    QPushButton *moreButton = new QPushButton(CancelButtonText);
    moreButton->setAutoDefault(false);

    ui->buttonBox->addButton(findButton, QDialogButtonBox::AcceptRole);
    ui->buttonBox->addButton(moreButton, QDialogButtonBox::RejectRole);
}

Settings::~Settings()
{
    delete ui;
}
//------------------------------------------------------------------------------------
void Settings::on_buttonBox_accepted()
{
HideAppCheckBox = ui->HideAppCheckBox1->isChecked();
PlayStationRadioButton = ui->PlayStationRadioButton1->isChecked();
PlayThisStationComboBox = ui->PlayThisStationComboBox1->itemText(ui->PlayThisStationComboBox1->currentIndex());
PlayLastStationRadioButton = ui->PlayLastStationRadioButton1->isChecked();
PlayStationAutomaticly = ui->PlayStationAutomaticly1->isChecked();
ShowStationsSystemTray = ui->ShowStationsSystemTrayComboBox1->isChecked();
ShowSystemTrayMessage = ui->ShowSystemTrayMessageCheckBox1->isChecked();
UILanguage = ui->LangcomboBox1->currentText();
}
//------------------------------------------------------------------------------------
void Settings::readSettings()
{
    QSettings settings("glrp", "Great Little Radio Player");

    settings.beginGroup("OtherSettings");
    HideAppCheckBox = settings.value("HideApp", false).toBool();
    PlayStationRadioButton = settings.value("PlayStation", false).toBool();
    PlayThisStationComboBox = settings.value("PlayThisStation", "").toString();
    PlayLastStationRadioButton = settings.value("PlayLastStation", false).toBool();
    PlayStationAutomaticly = settings.value("PlayAutomaticly", false).toBool();
    ShowStationsSystemTray = settings.value("ShowStationsSystemTray", false).toBool();
    ShowSystemTrayMessage = settings.value("ShowBaloonMessages", true).toBool();
    UILanguage = settings.value("UILanguage", "English").toString();

    settings.endGroup();

     ui->HideAppCheckBox1->setChecked(HideAppCheckBox);
     ui->PlayStationRadioButton1->setChecked(PlayStationRadioButton);
     ui->PlayThisStationComboBox1->setCurrentIndex(ui->PlayThisStationComboBox1->findText(PlayThisStationComboBox));
     ui->PlayThisStationComboBox1->setToolTip("<img src=':/images/IMG/note16.png'/>" + PlayThisStationComboBox);
     ui->PlayLastStationRadioButton1->setChecked(PlayLastStationRadioButton);
     ui->PlayStationAutomaticly1->setChecked(PlayStationAutomaticly);
     ui->ShowStationsSystemTrayComboBox1->setChecked(ShowStationsSystemTray);
     ui->ShowSystemTrayMessageCheckBox1->setChecked(ShowSystemTrayMessage);
     ui->LangcomboBox1->setCurrentIndex(ui->LangcomboBox1->findText(UILanguage));

     if (ui->PlayStationAutomaticly1->isChecked() && ui->PlayStationRadioButton1->isChecked())
     ui->PlayThisStationComboBox1->setEnabled(true);
}
//------------------------------------------------------------------------------------
void Settings::on_PlayStationRadioButton1_toggled(bool checked)
{
ui->PlayThisStationComboBox1->setEnabled(checked);
}
//------------------------------------------------------------------------------------
void Settings::LoadStationsToAutoPlayList()
{
//Tabela
TestTableWidget3 = new QTableWidget();

PathToStationsDir3 = QDir::homePath() + "/.config/glrp/";
PathToStationsFile3 = PathToStationsDir3 + "stations.csv";

QFile f( PathToStationsFile3 );

    if( f.open( QIODevice::ReadOnly ) )
    {
        QTextStream ts( &f );
        QList<QStringList> list;
        int row = 0, col = 0;


        while( !ts.atEnd() ){
            list << ts.readLine().split( "," );
        }

        f.close();

        TestTableWidget3->setRowCount( list.count() );
        TestTableWidget3->setColumnCount( list[0].count() );

        TestTableWidget3->setUpdatesEnabled( false );
        foreach( QStringList l, list ){
            foreach( QString str, l ){

                if( str.endsWith( '"' ) ) str.chop(1);
                if( str.startsWith( '"' ) ) str.remove(0,1);
                TestTableWidget3->setItem( row, col++, new QTableWidgetItem( str ));
            }
            row++; col=0;
        }
        TestTableWidget3->setUpdatesEnabled( true );
    }
//Kraj Tabele

    //Stringlists and populate
    QStringList StationsList;

    for (int i=0;i<TestTableWidget3->rowCount();i++)
        {
            StationsList << TestTableWidget3->item(i,0)->text();
        }
    StationsList.sort();
    StationsList.removeDuplicates();

    ui->PlayThisStationComboBox1->clear();
    ui->PlayThisStationComboBox1->addItems(StationsList);

    QIcon noteicon = QIcon(":/images/IMG/note16.png");
    for (int a = 0; a <  ui->PlayThisStationComboBox1->count(); a++)
    {
    ui->PlayThisStationComboBox1->setItemIcon(a,noteicon);
    }
}
//------------------------------------------------------------------------------------
void Settings::on_PlayThisStationComboBox1_currentIndexChanged(const QString &arg1)
{
    ui->PlayThisStationComboBox1->setToolTip("<img src=':/images/IMG/note16.png'/>" + arg1);
}
//------------------------------------------------------------------------------------
void Settings::ReadLanguage(QString Language)
{
    //Language Settings - MainWindow
    QSettings LangSettings("glrp/language", Language);
    LangSettings.beginGroup("Settings");
    LangSettingsTitle = LangSettings.value("LangSettingsTitle", "Settings").toString();
    LangSettingsInfo = LangSettings.value("LangSettingsInfo", "Here you can customize behavior of Great Little Radio Player.").toString();
    ui->tabWidget->setTabText(0,LangSettings.value("LangStartupTab", "On Start Up").toString());
    ui->tabWidget->setTabText(1,LangSettings.value("LangLookAndFeelTab", "Look").toString());
    ui->HideAppCheckBox1->setText(LangSettings.value("LangHideMainWindowCheckBox", "Hide main window on application startup\n(Icon in system tray).").toString());
    ui->PlayStationAutomaticly1->setTitle(LangSettings.value("PlayStationAutomaticly1", "Play stations automaticly").toString());
    ui->PlayStationRadioButton1->setText(LangSettings.value("PlayStationRadioButton1", "Play this station on application startup:").toString());
    ui->PlayLastStationRadioButton1->setText(LangSettings.value("PlayLastStationRadioButton1", "Play last played station").toString());
    ui->ShowStationsSystemTrayComboBox1->setText(LangSettings.value("ShowStationsSystemTray", "Show stations and categories in system tray menu\n(application restart is required)").toString());
    ui->ShowSystemTrayMessageCheckBox1->setText(LangSettings.value("ShowSystemTrayMessage", "Show baloon messages about playing station").toString());
    ui->groupBox->setTitle(LangSettings.value("LaguageGroupBox", "Language (change require application restart):").toString());

    CancelButtonText = LangSettings.value("CancelButtonText","Cancel").toString();
    OKButtonText = LangSettings.value("OKButtonText","OK").toString();

    LangSettings.endGroup();
}

void Settings::on_PlayStationAutomaticly1_toggled(bool arg1)
{
    if (ui->PlayStationAutomaticly1->isChecked() && ui->PlayStationRadioButton1->isChecked())
    ui->PlayThisStationComboBox1->setEnabled(arg1);
}
